@@ -1,60 +1,62 @@
 ''' Utility functions for point geometry '''
 
 from __future__ import annotations
-from typing import Sequence
+from typing import Union, Tuple
 
 import math
 from operator import mul
 from itertools import starmap
 
+XY = Union[Tuple[float, float], 'Point']
 
-def dot(a: Sequence[float], b: Sequence[Sequence[float]]) -> 'Point':
+
+def dot(a: XY, b: Tuple[Tuple[float, float], Tuple[float, float]]) -> 'Point':
     ''' Dot product of iterables a and b '''
     return Point([sum(starmap(mul, zip(a, col))) for col in zip(*b)])
 
 
-def linspace(start: float, stop: float, num: int=50) -> list[float]:
+def linspace(start: float, stop: float, num: int = 50) -> list[float]:
     ''' List of evenly spaced numbers '''
     step = (stop - start) / (num - 1)
     return [start+step*i for i in range(num)]
 
 
-def rotate(xy: Sequence[float],
+def rotate(xy: XY,
            angle: float,
-           center: Sequence[float]=(0, 0)) -> 'Point':
+           center: XY = (0, 0)) -> 'Point':
     ''' Rotate the xy point by angle degrees '''
     co = math.cos(math.radians(angle))
     so = math.sin(math.radians(angle))
     center = Point(center)
-    m = [[co, so], [-so, co]]  # rotation matrix
+    m = ((co, so), (-so, co))  # rotation matrix
     b = Point(xy) - center
     b = dot(b, m)
     b = b + center
     return b
 
 
-def mirrorx(xy, centerx=0) -> tuple[float, float]:
+def mirrorx(xy, centerx=0) -> Point:
     ''' Mirror the point horizontally '''
-    return -(xy[0]-centerx)+centerx, xy[1]
+    return Point((-(xy[0]-centerx)+centerx, xy[1]))
 
 
-def flip(xy: Sequence[float]) -> tuple[float, float]:
+def flip(xy: XY) -> Point:
     ''' Flip the point vertically '''
-    return xy[0], -xy[1]
+    return Point((xy[0], -xy[1]))
 
 
-def delta(a: Sequence[float], b: Sequence[float]) -> tuple[float, float]:
+def delta(a: XY, b: XY) -> Point:
     ''' Delta between points a and b '''
-    return b[0] - a[0], b[1] - a[1]
+    return Point((b[0] - a[0], b[1] - a[1]))
 
 
-def angle(a: Sequence[float], b: Sequence[float]) -> float:
+def angle(a: XY, b: XY) -> float:
     ''' Compute angle from point a to b '''
     theta = math.degrees(math.atan2(b[1] - a[1], b[0] - a[0]))
     return theta
 
 
-def dist(a: Sequence[float], b: Sequence[float]) -> float:
+def dist(a: XY, b: XY) -> float:
     ''' Get distance from point a to b.
 
         Same as math.dist in Python 3.8+.
@@ -99,7 +101,7 @@ class Point(tuple):
         except AttributeError:
             return Point((a-self.x, a-self.y))
 
-    def __mul__(self, a: float):
+    def __mul__(self, a: float):  # type: ignore
         return Point((a*self.x, a*self.y))
 
     def __truediv__(self, a: float):
@@ -109,13 +111,13 @@ class Point(tuple):
         return Point((-self.x, -self.y))
 
     __radd__ = __add__
-    __rmul__ = __mul__
+    __rmul__ = __mul__  # type: ignore
 
-    def rotate(self, angle: float, center: Sequence[float] = (0, 0)) -> 'Point':
+    def rotate(self, angle: float, center: XY = (0, 0)) -> 'Point':
         ''' Rotate the point by angle degrees about the center '''
         return Point(rotate(self, angle, center=Point(center)))
 
-    def mirrorx(self, centerx: float=0) -> 'Point':
+    def mirrorx(self, centerx: float = 0) -> 'Point':
         ''' Mirror in x direction about the centerx point '''
         return Point(mirrorx(self, centerx))
 
